@@ -25,7 +25,9 @@ public:
 
 private:
   void replaceIterators(const DeclStmt *D, ASTContext *Context);
-  void replaceNew(const DeclStmt *D, ASTContext *Context);
+  void replaceExpr(const DeclStmt *D, ASTContext *Context,
+                   std::function<QualType(const Expr *)> GetType,
+                   StringRef Message);
 
   const bool RemoveStars;
 };
