@@ -44,25 +44,22 @@ public:
 ModularizeUtilities::ModularizeUtilities(std::vector<std::string> &InputPaths,
                                          llvm::StringRef Prefix,
                                          llvm::StringRef ProblemFilesListPath)
-  : InputFilePaths(InputPaths),
-    HeaderPrefix(Prefix),
-    ProblemFilesPath(ProblemFilesListPath),
-    HasModuleMap(false),
-    MissingHeaderCount(0),
-    // Init clang stuff needed for loading the module map and preprocessing.
-    LangOpts(new LangOptions()), DiagIDs(new DiagnosticIDs()),
-    DiagnosticOpts(new DiagnosticOptions()),
-    DC(llvm::errs(), DiagnosticOpts.get()),
-    Diagnostics(
-    new DiagnosticsEngine(DiagIDs, DiagnosticOpts.get(), &DC, false)),
-    TargetOpts(new ModuleMapTargetOptions()),
-    Target(TargetInfo::CreateTargetInfo(*Diagnostics, TargetOpts)),
-    FileMgr(new FileManager(FileSystemOpts)),
-    SourceMgr(new SourceManager(*Diagnostics, *FileMgr, false)),
-    HeaderSearchOpts(new HeaderSearchOptions()),
-    HeaderInfo(new HeaderSearch(HeaderSearchOpts, *SourceMgr, *Diagnostics,
-    *LangOpts, Target.get())) {
-}
+    : InputFilePaths(InputPaths), HeaderPrefix(Prefix),
+      ProblemFilesPath(ProblemFilesListPath), HasModuleMap(false),
+      MissingHeaderCount(0),
+      // Init clang stuff needed for loading the module map and preprocessing.
+      LangOpts(new LangOptions()), DiagIDs(new DiagnosticIDs()),
+      DiagnosticOpts(new DiagnosticOptions()),
+      DC(llvm::errs(), DiagnosticOpts.get()),
+      Diagnostics(
+          new DiagnosticsEngine(DiagIDs, DiagnosticOpts.get(), &DC, false)),
+      TargetOpts(new ModuleMapTargetOptions()),
+      Target(TargetInfo::CreateTargetInfo(*Diagnostics, TargetOpts)),
+      FileMgr(new FileManager(FileSystemOpts)),
+      SourceMgr(new SourceManager(*Diagnostics, *FileMgr, false)),
+      HeaderInfo(new HeaderSearch(std::make_shared<HeaderSearchOptions>(),
+                                  *SourceMgr, *Diagnostics, *LangOpts,
+                                  Target.get())) {}
 
 // Create instance of ModularizeUtilities, to simplify setting up
 // subordinate objects.
@@ -75,9 +72,8 @@ ModularizeUtilities *ModularizeUtilities::createModularizeUtilities(
 
 // Load all header lists and dependencies.
 std::error_code ModularizeUtilities::loadAllHeaderListsAndDependencies() {
-  typedef std::vector<std::string>::iterator Iter;
   // For each input file.
-  for (Iter I = InputFilePaths.begin(), E = InputFilePaths.end(); I != E; ++I) {
+  for (auto I = InputFilePaths.begin(), E = InputFilePaths.end(); I != E; ++I) {
     llvm::StringRef InputPath = *I;
     // If it's a module map.
     if (InputPath.endswith(".modulemap")) {
@@ -345,9 +341,8 @@ bool ModularizeUtilities::collectModuleHeaders(const clang::Module &Mod) {
   DependentsVector UmbrellaDependents;
 
   // Recursively do submodules.
-  for (clang::Module::submodule_const_iterator MI = Mod.submodule_begin(),
-      MIEnd = Mod.submodule_end();
-      MI != MIEnd; ++MI)
+  for (auto MI = Mod.submodule_begin(), MIEnd = Mod.submodule_end();
+       MI != MIEnd; ++MI)
     collectModuleHeaders(**MI);
 
   if (const FileEntry *UmbrellaHeader = Mod.getUmbrellaHeader().Entry) {
